@@ -4,7 +4,7 @@
 #define NO_IMPORT_PYORBIT
 #include <pygobject.h>
 #include <pyorbit.h>
-#include <bonobo.h>
+#include <libbonobo.h>
 
 static void
 pybonobo_closure_invalidate(gpointer data, GClosure *closure)
